@@ -3,9 +3,9 @@ from .accuracy_validator import AccuracyValidator
 
 
 class ErrorValidator(AccuracyValidator):
-    def compute_score(self, src_val):
-        return 1 - super().compute_score(src_val)
+    """
+    Returns ```-(1-accuracy)```
+    """
 
-    @property
-    def maximize(self):
-        return False
+    def compute_score(self, src_val):
+        return -(1 - super().compute_score(src_val))
